# OpenDR Compressive Learning - Multilinear Compressive Learning method 

This module provides the implementation of the Multilinear Compressive Learning framework.

## Sources

The algorithm is implemented according to the paper [Multilinear Compressive Learning](https://arxiv.org/abs/1905.07481), based on [1](https://github.com/kuangliu/pytorch-cifar), [2](https://github.com/viebboy/MultilinearCompressiveLearningFramework), [3](https://github.com/viebboy/pytorch_trainer)
